==> openocd_0.5.0.orig.tar.bz2: openocd-0.5.0/src/target/arm946e.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Dominic Rath                                    *
 *   Dominic.Rath@gmx.de                                                   *
 *                                                                         *
 *   Copyright (C) 2008 by Spencer Oliver                                  *
 *   spen@spen-soft.co.uk                                                  *
 *                                                                         *
 *   Copyright (C) 2010 by Drasko DRASKOVIC                                *
 *   drasko.draskovic@gmail.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef ARM946E_H
#define ARM946E_H

#include "arm9tdmi.h"

#define	ARM946E_COMMON_MAGIC 0x20f920f9

struct arm946e_common
{
	struct arm7_9_common arm7_9_common;
	int common_magic;
	uint32_t cp15_control_reg;
};

static inline struct arm946e_common *
target_to_arm946(struct target *target)
{
	return container_of(target->arch_info, struct arm946e_common,
			arm7_9_common.armv4_5_common);
}

int arm946e_init_arch_info(struct target *target,
		struct arm946e_common *arm946e, struct jtag_tap *tap);
int arm946e_write_cp15(struct target *target, int reg_addr, uint32_t value);

extern const struct command_registration arm946e_command_handlers[];

#endif /* ARM946E_H */

==> openocd_0.10.0.orig.tar.bz2: openocd-0.10.0/src/target/arm946e.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Dominic Rath                                    *
 *   Dominic.Rath@gmx.de                                                   *
 *                                                                         *
 *   Copyright (C) 2008 by Spencer Oliver                                  *
 *   spen@spen-soft.co.uk                                                  *
 *                                                                         *
 *   Copyright (C) 2010 by Drasko DRASKOVIC                                *
 *   drasko.draskovic@gmail.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef OPENOCD_TARGET_ARM946E_H
#define OPENOCD_TARGET_ARM946E_H

#include "arm9tdmi.h"

#define ARM946E_COMMON_MAGIC 0x20f920f9

struct arm946e_common {
	struct arm7_9_common arm7_9_common;
	int common_magic;
	uint32_t cp15_control_reg;
	uint32_t cp15_cache_info;
};

static inline struct arm946e_common *target_to_arm946(struct target *target)
{
	return container_of(target->arch_info, struct arm946e_common,
			arm7_9_common.arm);
}

int arm946e_init_arch_info(struct target *target,
			   struct arm946e_common *arm946e, struct jtag_tap *tap);
int arm946e_write_cp15(struct target *target, int reg_addr, uint32_t value);

extern const struct command_registration arm946e_command_handlers[];

#endif /* OPENOCD_TARGET_ARM946E_H */
